/*
 * Copyright (c) 2015 by inovat, innovative systeme - verkehr - tunnel - technik, Dipl.-Ing. H. C. Kniss
 *
 * This file is part of de.bsvrz.kex.tls.osi7.conversion.Fg004Default
 *
 * de.bsvrz.kex.tls.osi7.conversion.Fg004Default is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  de.bsvrz.kex.tls.osi7.conversion.Fg004Default is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with de.bsvrz.kex.tls.osi7.conversion.Fg004Default.  If not, see <http://www.gnu.org/licenses/>.
 *
 *  Diese Datei ist Teil von de.bsvrz.kex.tls.osi7.conversion.Fg004Default.
 *
 *  de.bsvrz.kex.tls.osi7.conversion.Fg004Default ist Freie Software: Sie können es unter den Bedingungen
 *  der GNU General Public License, wie von der Free Software Foundation,
 *  Version 3 der Lizenz oder (nach Ihrer Wahl) jeder späteren
 *  veröffentlichten Version, weiterverbreiten und/oder modifizieren.
 *
 *  de.bsvrz.kex.tls.osi7.conversion.Fg004Default wird in der Hoffnung, dass es nützlich sein wird, aber
 *  OHNE JEDE GEWÄHRLEISTUNG, bereitgestellt; sogar ohne die implizite
 *  Gewährleistung der MARKTFÄHIGKEIT oder EIGNUNG FÜR EINEN BESTIMMTEN ZWECK.
 *  Siehe die GNU General Public License für weitere Details.
 *
 *  Sie sollten eine Kopie der GNU General Public License zusammen mit diesem
 *  Programm erhalten haben. Wenn nicht, siehe <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * inovat, Dipl.-Ing. H. C. Kniss
 * An der Krautwiese 37
 * D-53783 Eitorf
 * +49 (0)2243 8464 193
 * info@inovat.de
 * www.inovat.de
 */


package de.bsvrz.kex.tls.osi7.conversion;

//~ NICHT JDK IMPORTE =========================================================

import de.bsvrz.dav.daf.main.ClientDavInterface;
import de.bsvrz.kex.tls.osi7.De;
import de.bsvrz.kex.tls.osi7.Eak;
import de.bsvrz.sys.funclib.debug.Debug;

//~ JDK IMPORTE ===============================================================

//~ KLASSEN ===================================================================

/**
 * Umsetzungsmodul für die FG 4, Standard (alle Typen der FG 4 gemäß TLS 2002) Wird standardmäßig für alle FG 4 De
 * verwendet, bei denen keine spezielle Umsezungsklasse in der Konfiguration angegeben wurde. Erweiterung: unterstützt
 * auch nachgelieferte Telegramme (Standard ID+32)
 *
 * @author inovat, innovative systeme - verkehr - tunnel - technik
 * @author inovat, innovative systeme - verkehr - tunnel - technik
 * @version $Revision$ / $Date$ / ($Author$)
 */
public class Fg004DefaultMitAusschaltCode0 extends Fg004Default {

    // ------------------------------------------------------------------------
    // VARIABLENDEKLARATIONEN
    // ------------------------------------------------------------------------
    // Sonstige ---------------------------------------------------------------

    /** DebugLogger für Debug-Ausgaben */
    private static final Debug debug = Debug.getLogger();

    /**
     * Gültiger WvzCode, der beim Einschalten oder als Rückmeldung verwendet wurde. Da sich eine Reihe von
     * Softwareentwicklern für die SM/EAK-Software bei den Firmen auf eine etwas seltsame Interpretation der TLS im
     * Falle des Ausschaltens von WVZ-Anzeigen versteift (1), wird bis zur verbindlichen Festlegung einer vernünftigen
     * Interpretation ein WVZ beim Ausschalten jeweils mit dem letzten verschickten oder empfangenen WVZ-Code einer
     * Einschaltsequenz ausgeschaltet. (1) Das Schalten einer WVZ-Anzeige erfolgt über zwei Steuerbyte: dem eigentlichen
     * Befehl ob ein- oder auszuschalten ist und dem darzustellenden WVZ-Code. Letzterer macht logischerweise nur Sinn
     * beim Einschalten. Einige Entwickler versteifen sich aber darauf, dass auch beim Ausschalten ein gültiger Code
     * verwendet werden muss und schalten das WZG ansonsten nicht aus (obwohl kein Mensch erklären kann, warum hier so
     * ein unnötiger Programmieraufwand getrieben wird, der zudem einen sicheren Betrieb erheblich erschwert...Im
     * Zweifelsfall kann nämlich eine Fehlanzeige nicht ohne weiteres über eine Mánuelle Schaltung ausgeschaltet werden,
     * weil die Liste der gültigen Anzeigecode nicht bekannt ist!!).
     */
    private int _validWvzCode = 0;  // initial auf 0 setzen

    /**
     * Erzeugt ein Objekt vom Typ Fg004Default
     *
     * @param daf DaV
     * @param eak Eak
     * @param de  De
     */
    public Fg004DefaultMitAusschaltCode0(ClientDavInterface daf, Eak eak, De de) {
        super(daf, eak, de, true);
    }


    //~ METHODEN ==============================================================

    /**
     * Angepasste Version gegenüber {@link Fg004Default#bestimmungValidWvzCode(int)}. Setzt {@link #_validWvzCode} immer
     * auf 0 und liefert immer <code>true</code> zurück.
     *
     * @param code aktueller Code.
     *
     * @return Setzt {@link #_validWvzCode} immer auf 0 und liefert immer <code>true</code> zurück.
     */
    public boolean bestimmungValidWvzCode(int code) {
        _validWvzCode = 0;
        return true;
    }

    //~ GET METHODEN ==========================================================

    // ------------------------------------------------------------------------
    // GETTER / SETTER METHODEN
    // ------------------------------------------------------------------------
    public int getValidWvzCode() {
        return _validWvzCode;
    }
}

